monitorcontrol
**************

|PyPi Version| |Build Status| |Documentation Status| |Coverage Status| |Black|

Python monitor control using the VESA Monitor Control Command Set (MCCS)
over Display Data Channel Command Interface Standard (DDC-CI).


Documentation
#############

Full documentation including examples is available on readthedocs `here <https://monitorcontrol.readthedocs.io/en/latest/>`__.

.. |PyPi Version| image:: https://badge.fury.io/py/monitorcontrol.svg
   :target: https://badge.fury.io/py/monitorcontrol
.. |Build Status| image:: https://travis-ci.org/newAM/monitorcontrol.svg?branch=master
   :target: https://travis-ci.org/newAM/monitorcontrol
.. |Coverage Status| image:: https://coveralls.io/repos/github/newAM/monitorcontrol/badge.svg?branch=master
   :target: https://coveralls.io/github/newAM/monitorcontrol?branch=master
.. |Documentation Status| image:: https://readthedocs.org/projects/monitorcontrol/badge/?version=latest
   :target: https://monitorcontrol.readthedocs.io/en/latest/?badge=latest
.. |Black| image:: https://img.shields.io/badge/code%20style-black-000000.svg
	:target: https://github.com/psf/black
